Hirls.mad: Robust estimator for the linear regression model with Huber's...

View source: R/Hirls.r

Hirls.madR Documentation

Robust estimator for the linear regression model with Huber's weight function and MAD scal by iteratively re-weighted least squares (IRLS) algorithm

Description

Robust estimator for the linear regression model with Huber's weight function and MAD scal by iteratively re-weighted least squares (IRLS) algorithm

Usage

Hirls.mad(
  x1,
  y1,
  rt = rep(1, length(y1)),
  c1 = 1.44,
  rp.max = 150,
  cg.rt = 0.01
)

Arguments

x1

explanatory variable(s)

y1

objective variable

rt

sample weights

c1

tuning parameter from 1.44 to 2.88 for the scale parameter of MAD(Median Absolute Deviation)

rp.max

maximum number of iteration

cg.rt

convergence condition to stop iteration (default: cg1=0.001)

Value

a list with the following elements

HB

results of robust regression

wt

robust weights

rp

total number of iteration

s1

changes in scale through iterative calculation


robRatio documentation built on Nov. 5, 2025, 5:25 p.m.