RrT.aad: Robust estimator for a generalized ratio model with Tukey...

View source: R/RrT.r

RrT.aadR Documentation

Robust estimator for a generalized ratio model with Tukey biweight function and AAD scale by iteratively re-weighted least squares (IRLS) algorithm for M-estimation

Description

Robust estimator for a generalized ratio model with Tukey biweight function and AAD scale by iteratively re-weighted least squares (IRLS) algorithm for M-estimation

Usage

RrT.aad(x1, y1, g1 = 0.5, c1 = 8, rp.max = 100, cg.rt = 0.01)

Arguments

x1

single explanatory variable

y1

objective variable

g1

power (default: g1=0.5(conventional ratio model))

c1

tuning parameter usually from 4 to 8 (smaller figure is more robust)

rp.max

maximum number of iteration

cg.rt

convergence condition to stop iteration (default: cg1=0.001)

Value

a list with the following elements

par

robustly estimated ratio of y1 to x1

res

homoscedastic quasi-residuals

wt

robust weights

rp

total number of iteration

s1

changes in scale through iterative calculation

efg

error flag. 1: acalculia (all weights become zero) 0: successful termination


robRatio documentation built on Nov. 5, 2025, 5:25 p.m.