robGR: Robust estimator for a generalized ratio model

View source: R/robGR.r View source: R/robGR_bak.r

robGRR Documentation

Robust estimator for a generalized ratio model

Description

This function simultaneously estimates two parameters of the generalized ratio model doi:10.17713/ajs.v50i1.994. It uses Tukey's biweight function and AAD for scale of quasi residuals.

This robGR function simultaneously estimate two parameters of the generalized ratio model. It uses Tukey's biweight function and AAD for scale of quasi residuals.

Usage

robGR(x1, y1, g1 = 0, c1 = 8, rp.max = 100, cg.rt = 0.001)

robGR(x1, y1, g1 = 0, c1 = 8, rp.max = 100, cg.rt = 0.001)

Arguments

x1

single explanatory variable (a vector)

y1

objective variable to be imputed (a vector)

g1

initial gamma value (default g1=0.5)

c1

tuning constant for Tukey's biweight function. Supposed to choose 4 to 8. Smaller figure is more robust (default tp=8).

rp.max

maximum number of iteration (default: rp.max=50)

cg.rt

convergence condition to stop iteration (default: cg.rt=0.001)

Value

a list with the following elements

par

robustly estimated ratio of y1 to x1 (beta)

g1

robustly estimated power (gamma)

res

homoscedastic quasi-residuals

wt

robust weights

rp

total number of iteration

efg

error flag. 1: calculation not coverged, 0: successful termination

rt.cg

change of par(beta)

g1.cg

changes of g1(gamma)

s1.cg

changes of the scale(AAD)

a list with the following elements

par

robustly estimated ratio of y1 to x1 (beta)

g1

robustly estimated power (gamma)

res

homoscedastic quasi-residuals

wt

robust weights

rp

total number of iteration

efg

error flag. 1: calculation not coverged, 0: successful termination

rt.cg

change of par(beta)

g1.cg

changes of g1(gamma)

s1.cg

changes of the scale(AAD)


robRatio documentation built on Nov. 5, 2025, 5:25 p.m.