View source: R/robGR.r View source: R/robGR_bak.r
| robGR | R Documentation |
This function simultaneously estimates two parameters of the generalized ratio model doi:10.17713/ajs.v50i1.994. It uses Tukey's biweight function and AAD for scale of quasi residuals.
This robGR function simultaneously estimate two parameters of the generalized ratio model. It uses Tukey's biweight function and AAD for scale of quasi residuals.
robGR(x1, y1, g1 = 0, c1 = 8, rp.max = 100, cg.rt = 0.001)
robGR(x1, y1, g1 = 0, c1 = 8, rp.max = 100, cg.rt = 0.001)
x1 |
single explanatory variable (a vector) |
y1 |
objective variable to be imputed (a vector) |
g1 |
initial gamma value (default g1=0.5) |
c1 |
tuning constant for Tukey's biweight function. Supposed to choose 4 to 8. Smaller figure is more robust (default tp=8). |
rp.max |
maximum number of iteration (default: rp.max=50) |
cg.rt |
convergence condition to stop iteration (default: cg.rt=0.001) |
a list with the following elements
parrobustly estimated ratio of y1 to x1 (beta)
g1robustly estimated power (gamma)
reshomoscedastic quasi-residuals
wtrobust weights
rptotal number of iteration
efgerror flag. 1: calculation not coverged, 0: successful termination
rt.cgchange of par(beta)
g1.cgchanges of g1(gamma)
s1.cgchanges of the scale(AAD)
a list with the following elements
parrobustly estimated ratio of y1 to x1 (beta)
g1robustly estimated power (gamma)
reshomoscedastic quasi-residuals
wtrobust weights
rptotal number of iteration
efgerror flag. 1: calculation not coverged, 0: successful termination
rt.cgchange of par(beta)
g1.cgchanges of g1(gamma)
s1.cgchanges of the scale(AAD)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.